[Robast-commits] r637 - in branches/robast-0.9/pkg: ROptEst/R RobAStRDA/R RobAStRDA/man RobExtremes/R RobExtremes/inst/AddMaterial/interpolation RobExtremesBuffer

noreply at r-forge.r-project.org noreply at r-forge.r-project.org
Sat Mar 16 12:25:55 CET 2013


Author: ruckdeschel
Date: 2013-03-16 12:25:54 +0100 (Sat, 16 Mar 2013)
New Revision: 637

Modified:
   branches/robast-0.9/pkg/ROptEst/R/interpolLM.R
   branches/robast-0.9/pkg/RobAStRDA/R/interpolAux.R
   branches/robast-0.9/pkg/RobAStRDA/R/sysdata.rda
   branches/robast-0.9/pkg/RobAStRDA/man/internal-interpolate.Rd
   branches/robast-0.9/pkg/RobExtremes/R/interpolLM.R
   branches/robast-0.9/pkg/RobExtremes/inst/AddMaterial/interpolation/interpolationscripts.R
   branches/robast-0.9/pkg/RobExtremes/inst/AddMaterial/interpolation/plotInterpol.R
   branches/robast-0.9/pkg/RobExtremesBuffer/interpolMBREGEVFamily.csv
   branches/robast-0.9/pkg/RobExtremesBuffer/interpolMBREGammafamily.csv
   branches/robast-0.9/pkg/RobExtremesBuffer/interpolMBREGeneralizedParetoFamily.csv
   branches/robast-0.9/pkg/RobExtremesBuffer/interpolMBREWeibullFamily.csv
   branches/robast-0.9/pkg/RobExtremesBuffer/interpolOMSEGEVFamily.csv
   branches/robast-0.9/pkg/RobExtremesBuffer/interpolOMSEGammafamily.csv
   branches/robast-0.9/pkg/RobExtremesBuffer/interpolOMSEGeneralizedParetoFamily.csv
   branches/robast-0.9/pkg/RobExtremesBuffer/interpolOMSEWeibullFamily.csv
   branches/robast-0.9/pkg/RobExtremesBuffer/interpolRMXEGeneralizedParetoFamily.csv
Log:
All but 3 grids recomputed (with NA-entries omitted); only .RMXE-Gamma,-Weibull,-GEV are not yet redone.
On first inspection they have improved a lot, but still, some have to be smoothed ... 

RobAStRDA: Smoothing parameter df of .MakeSmoothGridList can now be adjusted coordinatewise,
 and smoothing can be restricted to specific thGrid values by argument gridRestrForSmooth 
  -- see ?.MakeSmoothGridList
plotInterpol gains functionality for interactive try out of smoothing parameters


Modified: branches/robast-0.9/pkg/ROptEst/R/interpolLM.R
===================================================================
--- branches/robast-0.9/pkg/ROptEst/R/interpolLM.R	2013-03-15 14:12:31 UTC (rev 636)
+++ branches/robast-0.9/pkg/ROptEst/R/interpolLM.R	2013-03-16 11:25:54 UTC (rev 637)
@@ -172,7 +172,7 @@
             getFun = .getLMGrid, ..., modifyfct, nameInSysdata,
             GridFileName, withPrint = TRUE){
   if(missing(GridFileName))
-     GridFileName <- paste(sub("^\\.(.+)","\\1",nameInSysdata),".Rdata",sep="")
+     GridFileName <- paste(gsub("^\\.(.+)","\\1",nameInSysdata),".Rdata",sep="")
   Grid <- getFun(thGrid = thGrid, PFam = PFam, ..., modifyfct = modifyfct,
                  withPrint = withPrint, GridFileName = GridFileName)
   .saveGridToCSV(Grid,toFileCSV,name(PFam),nameInSysdata)

Modified: branches/robast-0.9/pkg/RobAStRDA/R/interpolAux.R
===================================================================
--- branches/robast-0.9/pkg/RobAStRDA/R/interpolAux.R	2013-03-15 14:12:31 UTC (rev 636)
+++ branches/robast-0.9/pkg/RobAStRDA/R/interpolAux.R	2013-03-16 11:25:54 UTC (rev 637)
@@ -2,11 +2,25 @@
     paste(sep="", name, if(getRversion()<"2.16") ".O" else ".N")
 }
 
-.MakeSmoothGridList <- function(thGrid, Y, df=NULL){
+.MakeSmoothGridList <- function(thGrid, Y, df = NULL,
+                            gridRestrForSmooth = NULL){
    if(length(dim(Y))==3)
       LMGrid <- Y[,1,,drop=TRUE]
    else LMGrid <- Y[,drop=FALSE]
 
+  if(!is.null(df)){
+    df0 <- vector("list",ncol(LMGrid))
+    if(is.numeric(df)){
+    df <- rep(df,length.out=ncol(LMGrid))
+    for(i in 1:ncol(LMGrid)) df0[[i]] <- df[i]
+    df <- df0
+    }
+  }else{
+    df0 <- vector("list",ncol(LMGrid)+1)
+    df0[[ncol(LMGrid)+1]] <- NULL
+    df <- df0
+  }
+
    iNA <- apply(LMGrid,1, function(u) any(is.na(u)))
    LMGrid <- LMGrid[!iNA,,drop=FALSE]
    thGrid <- thGrid[!iNA]
@@ -14,9 +28,33 @@
    thGrid <- thGrid[oG]
    LMGrid <- LMGrid[oG,,drop=FALSE]
 
-   LMGrid <- apply(LMGrid,2,function(u) if(is.null(df))
-                  smooth.spline(thGrid,u)$y else smooth.spline(thGrid,u,df=df)$y
-                  )
+   if(is.null(gridRestrForSmooth))
+      gridRestrForSmooth <- as.data.frame(matrix(TRUE,nrow(LMGrid),ncol(LMGrid)))
+   if((is.vector(gridRestrForSmooth)&&!is.list(gridRestrForSmooth))||
+       is.matrix(gridRestrForSmooth))
+      gridRestrForSmooth <- as.data.frame(gridRestrForSmooth)
+
+   if(is.list(gridRestrForSmooth)){
+      gm <- vector("list",ncol(LMGrid))
+      idx <- rep(1:length(gridRestrForSmooth), length.out=ncol(LMGrid))
+      for (i in 1:ncol(LMGrid)){
+           if(!is.null(gridRestrForSmooth[[idx[i]]])){
+               gm[[i]] <- gridRestrForSmooth[[idx[i]]]
+           }else{
+               gm[[i]] <- rep(TRUE,nrow(LMGrid))
+           }
+      }
+      gridRestrForSmooth <- gm
+   }
+
+   for(i in 1:ncol(LMGrid)){
+       gmi <- gridRestrForSmooth[[i]]
+       if(is.null(df[[i]])){
+          LMGrid[gmi,i] <- smooth.spline(thGrid[gmi],LMGrid[gmi,i])$y
+       } else {
+          LMGrid[gmi,i] <- smooth.spline(thGrid[gmi],LMGrid[gmi,i],df=df[[i]])$y
+       }
+   }
    return(cbind(xi=thGrid,LM=LMGrid))
 }
 
@@ -86,7 +124,8 @@
 ############################################################################
 .saveGridToRda <- function(fromFileCSV, toFileRDA = "sysdata.rda",
                            withMerge =FALSE, withPrint = TRUE,
-                           withSmooth = TRUE, df = NULL){
+                           withSmooth = TRUE, df = NULL,
+                           gridRestrForSmooth = NULL){
 
   ### check whether input is complete
   if(missing(fromFileCSV)) stop("You must specify argument 'fromFileCSV'.")
@@ -96,7 +135,6 @@
   ## and new grids
   newEnv <- new.env()
 
-
   ### determine what objects already exist in sysdata.rda - type file
   if(file.exists(toFileRDA)){
      load(file=toFileRDA,envir=newEnv)
@@ -137,13 +175,13 @@
                    if(withSmooth)
                       InterpGrids[[namPFam]]$gridS <-
                         .MakeSmoothGridList(gr0[,1],gr0[,-1,drop=FALSE],
-                                            df = df)
+                            df = df, gridRestrForSmooth = gridRestrForSmooth)
                    cat(gettext("Grid successfully merged.\n"))
                 }else{
                    InterpGrids[[namPFam]]$grid <- Grid
                    InterpGrids[[namPFam]]$gridS <-
                         .MakeSmoothGridList(Grid[,1],Grid[,-1,drop=FALSE],
-                                            df = df)
+                            df = df, gridRestrForSmooth = gridRestrForSmooth)
                    cat(gettext("Grid successfully overwritten.\n"))
                 }
                 l.ng <- -1
@@ -158,7 +196,8 @@
       if(l.ng>0){ ## a new family is entered
          InterpGrids[[l.ng]]$grid <- Grid
          InterpGrids[[l.ng]]$gridS <-
-              .MakeSmoothGridList(Grid[,1], Grid[,-1,drop = FALSE], df = df)
+              .MakeSmoothGridList(Grid[,1], Grid[,-1,drop = FALSE],
+                            df = df, gridRestrForSmooth = gridRestrForSmooth)
          cat(gettext("New Grid successfully produced.\n"))
          names(InterpGrids)[l.ng] <- namPFam
       }
@@ -257,7 +296,8 @@
 }
 
 .copy_smoothGrid <- function(gridEntry = NULL, rdafileOld, gridnamOld, FamnamOld,
-                 rdafileNew, gridnamNew, FamnamNew, withSmooth = FALSE, df = NULL){
+                 rdafileNew, gridnamNew, FamnamNew, withSmooth = FALSE,
+                 df = NULL, gridRestrForSmooth = NULL){
 
   if(missing(rdafileOld)) stop("Argument 'rdafileOld' must not be missing.")
   if(missing(gridnamOld)) stop("Argument 'gridnamOld' must not be missing.")
@@ -273,7 +313,8 @@
      gridEntry <- gr[[FamnamOld]]$grid  else  gr[[FamnamNew]]$grid <- gridEntry
   if(withSmooth){
         gr[[FamnamNew]]$gridS <- .MakeSmoothGridList(gridEntry[,1],
-                                    gridEntry[,-1, drop = FALSE],  df = df)
+                                    gridEntry[,-1, drop = FALSE],  df = df,
+                                    gridRestrForSmooth = gridRestrForSmooth)
   }else gr[[FamnamNew]]$gridS <- NULL
   assign(gridnamNew,gr,envir=nE)
   what <- ls(envir=nE, all.names = TRUE)

Modified: branches/robast-0.9/pkg/RobAStRDA/R/sysdata.rda
===================================================================
(Binary files differ)

Modified: branches/robast-0.9/pkg/RobAStRDA/man/internal-interpolate.Rd
===================================================================
--- branches/robast-0.9/pkg/RobAStRDA/man/internal-interpolate.Rd	2013-03-15 14:12:31 UTC (rev 636)
+++ branches/robast-0.9/pkg/RobAStRDA/man/internal-interpolate.Rd	2013-03-16 11:25:54 UTC (rev 637)
@@ -23,14 +23,15 @@
 \usage{
 .versionSuff(name)
 
-.MakeSmoothGridList(thGrid, Y, df=NULL)
+.MakeSmoothGridList(thGrid, Y, df = NULL, gridRestrForSmooth = NULL)
 
 .readGridFromCSV(fromFileCSV)
 
 .generateInterpolators(Grid, approxOrspline = "spline", extrapol = c(NA,NA))
 
 .saveGridToRda(fromFileCSV, toFileRDA = "sysdata.rda", withMerge = FALSE,
-               withPrint = TRUE, withSmooth = TRUE, df = NULL)
+               withPrint = TRUE, withSmooth = TRUE, df = NULL,
+               gridRestrForSmooth = NULL)
 
 .mergeGrid(Grid1, Grid2)
 
@@ -44,7 +45,8 @@
         excludeGrids = NULL, excludeNams = NULL)
 
 .copy_smoothGrid(gridEntry = NULL, rdafileOld, gridnamOld, FamnamOld, rdafileNew,
-                 gridnamNew, FamnamNew, withSmooth = FALSE, df = NULL)
+                 gridnamNew, FamnamNew, withSmooth = FALSE, df = NULL,
+                 gridRestrForSmooth = NULL)
 
 .renameGridName(rdafileOld, gridnamOld, FamnamOld, rdafileNew, gridnamNew,
                 FamnamNew)
@@ -59,7 +61,19 @@
            contains precomputed y-values, so that call to \code{getFun}
            resp. \code{optFct} can be omitted. }
   \item{df}{argument \code{df} of \code{\link{smooth.spline}}; if \code{NULL}
-            (default) it is omitted; controls the degree to which we smooth.}
+            (default) it is omitted (and the default of
+            \code{\link{smooth.spline}} used); controls the degree to which
+            we smooth; can be vectorized; to allow for \code{NULL}-entries
+            in some (of the 13) LMs, it can also be a list of length 13,
+            some entries being \code{NULL}, some numeric. }
+  \item{gridRestrForSmooth}{an expression that can be used as index in
+     \code{theta[gridRestrForSmooth]} to restrict the grid-values to
+     be smoothed; the excluded grid values are left unchanged. If the argument
+     is \code{NULL} no restriction is used. Can be a matrix of same dimension
+     as the \code{Y}-grid to allow for column-individual restrictions,
+     or a list of same length as number of columns of \code{Y}
+     with columnwise restrictions of \code{Y} (and \code{NULL} entries
+     are interpreted as no restriction). }
   \item{fromFileCSV}{character; names of the csv files from which the grids are
                      read. }
   \item{Grid, gridEntry}{matrix; grid to be used. }

Modified: branches/robast-0.9/pkg/RobExtremes/R/interpolLM.R
===================================================================
--- branches/robast-0.9/pkg/RobExtremes/R/interpolLM.R	2013-03-15 14:12:31 UTC (rev 636)
+++ branches/robast-0.9/pkg/RobExtremes/R/interpolLM.R	2013-03-16 11:25:54 UTC (rev 637)
@@ -40,7 +40,7 @@
                    loRad.s=0.2, up.Rad.s=1,
                    withStartLM = TRUE){
              namF <- gsub("\\.th$","",paste(deparse(substitute(optF))))
-             namF <- gsub("^\\.(.+)","\\1",namF)
+             namF <- gsub(" ", "",namF))
              to <- gsub("XXXX",gsub(" ","",name(PFam)),
                     gsub("YYYY", namF, "interpolYYYYXXXX.csv"))
              print(to)

Modified: branches/robast-0.9/pkg/RobExtremes/inst/AddMaterial/interpolation/interpolationscripts.R
===================================================================
--- branches/robast-0.9/pkg/RobExtremes/inst/AddMaterial/interpolation/interpolationscripts.R	2013-03-15 14:12:31 UTC (rev 636)
+++ branches/robast-0.9/pkg/RobExtremes/inst/AddMaterial/interpolation/interpolationscripts.R	2013-03-16 11:25:54 UTC (rev 637)
@@ -25,7 +25,7 @@
 #    RobExtremes:::.generateInterpGridSn(PFam = PF)}
 ## to make this parallel, start this on several processors
 #.svInt1()
-#.svInt(.OMSE.th, PFam=PF)
+.svInt(.OMSE.th, PFam=PF, xiGrid = getShapeGrid(3, cutoff.at.0=0.005))
 #.svInt(.MBRE.th, PFam=PF)
 .svInt(.RMXE.th, PFam=PF)
 setwd(oldwd)

Modified: branches/robast-0.9/pkg/RobExtremes/inst/AddMaterial/interpolation/plotInterpol.R
===================================================================
--- branches/robast-0.9/pkg/RobExtremesBuffer/interpolMBREGEVFamily.csv	2013-03-15 14:12:31 UTC (rev 636)
+++ branches/robast-0.9/pkg/RobExtremesBuffer/interpolMBREGEVFamily.csv	2013-03-16 11:25:54 UTC (rev 637)
@@ -1,492 +1,506 @@
-" 5.00000000000000010408e-03" " 1.81357633287360164864e+00" "-2.24449754695824399420e-01" "-1.47885705270914519227e-01" "-4.58921540973249220130e-01" "-1.81549049260172734588e-01" " 5.18224508955159923751e-01" "-7.33531573128324149158e-02" "-7.36695431812270096206e-02" " 1.00000000000000000000e+00" " 5.18224508955159923751e-01" "-7.33531573128324149158e-02" "-7.36695431812270096206e-02" " 1.00000000000000000000e+00"
-" 2.14517304631997030029e-02" " 1.82170362017730180781e+00" "-2.21448911244242041541e-01" "-1.50355403686426691845e-01" "-4.55269605129110077613e-01" "-1.76720769852665327004e-01" " 5.08063065632790911152e-01" "-5.82186275198257746633e-02" "-5.77077143417919283253e-02" " 1.00000000000000000000e+00" " 5.08143619270839841384e-01" "-5.80051768448633583986e-02" "-5.81911274646265477828e-02" " 1.00000000000000000000e+00"
-" 3.98406374501992024961e-02" " 1.83083370984061777342e+00" "-2.17035963582212471090e-01" "-1.51512983390812039364e-01" "-4.54345392222172295149e-01" "-1.72894960142815801163e-01" " 4.96136067101396682766e-01" "-4.74932769628111234317e-02" "-4.86195811306312300482e-02" " 1.00000000000000000000e+00" " 4.95936248408226754147e-01" "-4.77016787664086075460e-02" "-4.85995950036596374710e-02" " 1.00000000000000000000e+00"
-" 4.27829746040001568375e-02" " 1.83229759826328653105e+00" "-2.16118212042312296539e-01" "-1.52374008396431198653e-01" "-4.52639888751594832161e-01" "-1.72932720214651891588e-01" " 4.94720174340536444912e-01" "-4.54195759788707867366e-02" "-4.51729009100261397203e-02" " 1.00000000000000000000e+00" " 4.94720174340536444912e-01" "-4.54195759788707867366e-02" "-4.51729009100261397203e-02" " 1.00000000000000000000e+00"
-" 6.40397156295258174197e-02" " 1.84287543551152532828e+00" "-2.09674326233737051695e-01" "-1.54762162850679618753e-01" "-4.48045578614404638174e-01" "-1.66938935089539775003e-01" " 4.81144590091446000546e-01" "-2.80584353688964997786e-02" "-3.19411963298408749234e-02" " 1.00000000000000000000e+00" " 4.80470980864551755474e-01" "-2.87525051330816128203e-02" "-3.19533813366238497733e-02" " 1.00000000000000000000e+00"
-" 7.96812749003984049923e-02" " 1.85070371763565866274e+00" "-2.08536238317104577478e-01" "-1.56919373979981485734e-01" "-4.45272376876807263191e-01" "-1.65208357534006367029e-01" " 4.76384421706800675889e-01" "-1.95038700097885028817e-02" "-2.00647499048494833140e-02" " 1.00000000000000000000e+00" " 4.75947149369317923373e-01" "-1.97086007479972957768e-02" "-2.02230671057971982119e-02" " 1.00000000000000000000e+00"
-" 8.52248570399394278496e-02" " 1.85347985392406511274e+00" "-2.07900841379440981527e-01" "-1.57705602351155882435e-01" "-4.45456845353655817021e-01" "-1.64450967560591382322e-01" " 4.73547754619834226908e-01" "-1.47010272358679451588e-02" "-1.46008738936339865777e-02" " 1.00000000000000000000e+00" " 4.73190003587921015349e-01" "-1.54744589399295820464e-02" "-1.47551495011547725844e-02" " 1.00000000000000000000e+00"
-" 1.06341241002067987687e-01" " 1.86407717660864613585e+00" "-2.04038293795141795206e-01" "-1.60749650474153876756e-01" "-4.40849240782102969050e-01" "-1.60979520513820612004e-01" " 4.62876655217478893967e-01" " 9.72114778390573863092e-05" "-8.42891877730452790569e-04" " 1.00000000000000000000e+00" " 4.62173942462537512554e-01" "-7.70146016848490032672e-05" "-1.28603273751948785943e-03" " 1.00000000000000000000e+00"
-" 1.19521912350597614427e-01" " 1.87071107891449406324e+00" "-2.01555709907786650970e-01" "-1.61798168032950273609e-01" "-4.39355126712112520337e-01" "-1.58267308423409414075e-01" " 4.56173937376610993955e-01" " 7.99529334775864186646e-03" " 7.98285749610598907577e-03" " 1.00000000000000000000e+00" " 4.56243546526286347653e-01" " 8.08383164904142269280e-03" " 7.97491549049226915169e-03" " 1.00000000000000000000e+00"
-" 1.27391651478953704668e-01" " 1.87467845381020259410e+00" "-1.99887198519305114841e-01" "-1.62214108649143956553e-01" "-4.35652477622920419886e-01" "-1.56162774606530135868e-01" " 4.53276494006642161061e-01" " 1.32964504467802183130e-02" " 1.30645222855357446418e-02" " 1.00000000000000000000e+00" " 4.53783095362249866422e-01" " 1.29589301251803803994e-02" " 1.19070988677393678479e-02" " 1.00000000000000000000e+00"
-" 1.48378817222630354777e-01" " 1.88528306742171802846e+00" "-1.96857494101617430671e-01" "-1.64894436497434737632e-01" "-4.33483972627471070282e-01" "-1.53146635514376988629e-01" " 4.44055568874093808951e-01" " 2.76925977606299264511e-02" " 2.76782765166379354782e-02" " 1.00000000000000000000e+00" " 4.43582440347021933480e-01" " 2.65155609011622182825e-02" " 2.73437746621024158067e-02" " 1.00000000000000000000e+00"
-" 1.59362549800796809985e-01" " 1.89084580370348631639e+00" "-1.94459975649268451692e-01" "-1.65167490222664581356e-01" "-4.31789965496753858076e-01" "-1.50578102907902772190e-01" " 4.38181637859916706113e-01" " 3.32399220716845036905e-02" " 3.37822257687323684872e-02" " 1.00000000000000000000e+00" " 4.38045516927180411670e-01" " 3.33810518567187394789e-02" " 3.35127512956347253792e-02" " 1.00000000000000000000e+00"
-" 1.69305414639138729349e-01" " 1.89588500206250176738e+00" "-1.92237411020182491495e-01" "-1.66712756361419578433e-01" "-4.28597609342009910893e-01" "-1.48468578659457506319e-01" " 4.33485765860617155987e-01" " 4.21763540139890938385e-02" " 4.31078513011782862852e-02" " 1.00000000000000000000e+00" " 4.34135195703849285920e-01" " 4.24271326560168374198e-02" " 4.29721595962449867678e-02" " 1.00000000000000000000e+00"
-" 1.90174070534208650152e-01" " 1.90650237952790413409e+00" "-1.90446388794238752329e-01" "-1.68062321880127041318e-01" "-4.28633064041238465158e-01" "-1.45075414580951467247e-01" " 4.26066359533377736479e-01" " 5.36284044036416385204e-02" " 5.39047890722203978942e-02" " 1.00000000000000000000e+00" " 4.26066359533377736479e-01" " 5.36284044036416385204e-02" " 5.39047890722203978942e-02" " 1.00000000000000000000e+00"
-" 1.99203187250996005542e-01" " 1.91110176606159587465e+00" "-1.88579437506588371010e-01" "-1.70162076561279212994e-01" "-4.25592052015728139480e-01" "-1.45216175407850839330e-01" " 4.23417579929574350306e-01" " 5.86145841664037423047e-02" " 5.76814585654925882086e-02" " 1.00000000000000000000e+00" " 4.23417579929574350306e-01" " 5.86145841664037423047e-02" " 5.76814585654925882086e-02" " 1.00000000000000000000e+00"
-" 2.10987364747485084404e-01" " 1.91711834734776820355e+00" "-1.86679259952975490355e-01" "-1.70757163695493652256e-01" "-4.24386593128949107800e-01" "-1.42636944401326126730e-01" " 4.17790926687134411832e-01" " 6.62608568447949491942e-02" " 6.57220468047886308138e-02" " 1.00000000000000000000e+00" " 4.17790926687134411832e-01" " 6.62608568447949491942e-02" " 6.57220468047886308138e-02" " 1.00000000000000000000e+00"
-" 2.31747832682678900351e-01" " 1.92773776737950242044e+00" "-1.83940932931882183965e-01" "-1.72109598457032775265e-01" "-4.22266145537809611810e-01" "-1.38694450737669700002e-01" " 4.09502187334504830218e-01" " 7.91329072256186927259e-02" " 7.94698175609502288630e-02" " 1.00000000000000000000e+00" " 4.09502187334504830218e-01" " 7.91329072256186927259e-02" " 7.94698175609502288630e-02" " 1.00000000000000000000e+00"
-" 2.39043824701195228855e-01" " 1.93147517605161533893e+00" "-1.81763340762608666124e-01" "-1.72681402409168516243e-01" "-4.21329960451714891079e-01" "-1.37452475630147369356e-01" " 4.05966050944434997394e-01" " 8.29164515404993973657e-02" " 8.11334542709693240514e-02" " 1.00000000000000000000e+00" " 4.05831068620737756003e-01" " 8.28745767717891240745e-02" " 8.05291380045802113186e-02" " 1.00000000000000000000e+00"
-" 2.52457967740567557069e-01" " 1.93836271992803976794e+00" "-1.81193463000845739197e-01" "-1.73696000746715789598e-01" "-4.21566265058053224468e-01" "-1.35232767124049885199e-01" " 4.01626384085670862234e-01" " 9.07734428262826908984e-02" " 9.09128963056798911069e-02" " 1.00000000000000000000e+00" " 4.01202888644781818783e-01" " 9.05245364891092141324e-02" " 9.08481781051470455024e-02" " 1.00000000000000000000e+00"
-" 2.73120223661343919375e-01" " 1.94897581408296471928e+00" "-1.80642441275651322030e-01" "-1.74982015704197968464e-01" "-4.18442575258591964449e-01" "-1.31988728559020607189e-01" " 3.98561451113740139451e-01" " 1.02662100775652923024e-01" " 1.06098594111868102519e-01" " 1.00000000000000000000e+00" " 3.98533328094621885906e-01" " 1.03058527463250615419e-01" " 1.06139878813551385983e-01" " 1.00000000000000000000e+00"
-" 2.78884462151394396656e-01" " 1.95194394392986336761e+00" "-1.78187632330723821905e-01" "-1.76234227016729749771e-01" "-4.15002474446507063632e-01" "-1.30785600600483303824e-01" " 3.94567167725847323112e-01" " 1.08643377250491196540e-01" " 1.09935595401980640284e-01" " 1.00000000000000000000e+00" " 3.94371237747624170389e-01" " 1.08692728041646993753e-01" " 1.09787604138102262707e-01" " 1.00000000000000000000e+00"
-" 2.93737016782436521911e-01" " 1.95962867002094442981e+00" "-1.76006233890053570557e-01" "-1.76017903375845441438e-01" "-4.16800091535223737882e-01" "-1.28693807115416308795e-01" " 3.87804254369114642653e-01" " 1.13410200785950654456e-01" " 1.13426633450955605120e-01" " 1.00000000000000000000e+00" " 3.87939814110230318800e-01" " 1.14074870338533571057e-01" " 1.13688684562727390648e-01" " 1.00000000000000000000e+00"
-" 3.14310728217555401809e-01" " 1.97026989402602570323e+00" "-1.73962045758433991871e-01" "-1.77481607760214848968e-01" "-4.14027685138004641896e-01" "-1.25963102842284985217e-01" " 3.82104927124610749267e-01" " 1.24625951561890491170e-01" " 1.25527481256040573943e-01" " 1.00000000000000000000e+00" " 3.81778214194348819444e-01" " 1.25144095510945130290e-01" " 1.25607978091816896438e-01" " 1.00000000000000000000e+00"
-" 3.18725099601593619969e-01" " 1.97255818998371390549e+00" "-1.72930735663139184544e-01" "-1.77396585573541570868e-01" "-4.14617703253063241142e-01" "-1.25023321084555105731e-01" " 3.79822070451222959520e-01" " 1.26714900424334059315e-01" " 1.26567392892025870621e-01" " 1.00000000000000000000e+00" " 3.79874906239952569997e-01" " 1.26520740164107220460e-01" " 1.26105531774140161572e-01" " 1.00000000000000000000e+00"
-" 3.34843705962408810795e-01" " 1.98092047684842320621e+00" "-1.70274678679581847884e-01" "-1.78653429787690998243e-01" "-4.11405942071117913805e-01" "-1.22559331200983445687e-01" " 3.74273701693347726760e-01" " 1.35105329417008812598e-01" " 1.34639811515937790620e-01" " 1.00000000000000000000e+00" " 3.75023191821807655444e-01" " 1.34899359350960618142e-01" " 1.34486391473781496941e-01" " 1.00000000000000000000e+00"
-" 3.55338266932213375782e-01" " 1.99157793193281995592e+00" "-1.68861891788168239081e-01" "-1.79639101585473831557e-01" "-4.11150470518950039711e-01" "-1.19540594776575456737e-01" " 3.68169473181114925708e-01" " 1.45289041499842536131e-01" " 1.45421399548979396465e-01" " 1.00000000000000000000e+00" " 3.68064423103658278080e-01" " 1.45792833916735392608e-01" " 1.45316827492299294189e-01" " 1.00000000000000000000e+00"
-" 3.58565737051792843282e-01" " 1.99325928201677005092e+00" "-1.68088152730626105846e-01" "-1.79452621871856787816e-01" "-4.09589497898819043797e-01" "-1.19673053303831891658e-01" " 3.67480477614653910923e-01" " 1.47206845764279753430e-01" " 1.46780561910211160281e-01" " 1.00000000000000000000e+00" " 3.67474659119407243146e-01" " 1.47459142783165964019e-01" " 1.47962385967833898182e-01" " 1.00000000000000000000e+00"
-" 3.75796698935874085024e-01" " 2.00224356895539079559e+00" "-1.66005387539434834387e-01" "-1.81003722800379907021e-01" "-4.06967311905129858207e-01" "-1.17838238962381824937e-01" " 3.62328485487730389547e-01" " 1.56820365956303525712e-01" " 1.56022823204245209006e-01" " 1.00000000000000000000e+00" " 3.61635512408597481482e-01" " 1.56070359999738145218e-01" " 1.55466379955065903129e-01" " 1.00000000000000000000e+00"
-" 3.96221262591437028977e-01" " 2.01292114203179650644e+00" "-1.64134541183186599689e-01" "-1.81573549339193895946e-01" "-4.06599260011305418949e-01" "-1.14112339796905826184e-01" " 3.57268523744273480691e-01" " 1.65915721392144999147e-01" " 1.65358311266045665544e-01" " 1.00000000000000000000e+00" " 3.57268523744273480691e-01" " 1.65915721392144999147e-01" " 1.65358311266045665544e-01" " 1.00000000000000000000e+00"
-" 3.98406374501992011083e-01" " 2.01406465801608414168e+00" "-1.63359347492141315783e-01" "-1.81938559261247578824e-01" "-4.05678540777555496355e-01" "-1.14427869102482024366e-01" " 3.56033522051043826995e-01" " 1.66452880346637521747e-01" " 1.65506458432017722338e-01" " 1.00000000000000000000e+00" " 3.56557012749407875596e-01" " 1.66351599423153695412e-01" " 1.65339643993273971434e-01" " 1.00000000000000000000e+00"
-" 4.16614193187194392642e-01" " 2.02360826783990788158e+00" "-1.61392940998634243366e-01" "-1.82197107971740934751e-01" "-4.05639702646240607464e-01" "-1.11070945291743189420e-01" " 3.50654327495739881471e-01" " 1.75118142318103936494e-01" " 1.74769579041459566238e-01" " 1.00000000000000000000e+00" " 3.50599447604181935212e-01" " 1.75348510505069499210e-01" " 1.74970046192169104149e-01" " 1.00000000000000000000e+00"
-" 4.36977702492617525731e-01" " 2.03428881590178090022e+00" "-1.59825364420835946966e-01" "-1.83414104447304965317e-01" "-4.04327742817793267527e-01" "-1.09131151937912437844e-01" " 3.45995951816330360451e-01" " 1.84186595150317961034e-01" " 1.83698505075733431458e-01" " 1.00000000000000000000e+00" " 3.45735671727974147593e-01" " 1.84351934846023718384e-01" " 1.84531191536261823805e-01" " 1.00000000000000000000e+00"
-" 4.38247011952191289907e-01" " 2.03493201787984778761e+00" "-1.61778956011384394964e-01" "-1.84741390458027010535e-01" "-4.05503606289195905887e-01" "-1.08596093193116055575e-01" " 3.47437982832751679485e-01" " 1.87795107561500446147e-01" " 1.90948175287012411605e-01" " 1.00000000000000000000e+00" " 3.47611900608600532525e-01" " 1.87625603312824018598e-01" " 1.91117931239299876367e-01" " 1.00000000000000000000e+00"
-" 4.57313980523084140373e-01" " 2.04499990318908952958e+00" "-1.57632954978096817555e-01" "-1.83818106139373937946e-01" "-4.03785849182797584866e-01" "-1.05458860259442885332e-01" " 3.40610817976483515324e-01" " 1.93784740638320546191e-01" " 1.93531549138136999000e-01" " 1.00000000000000000000e+00" " 3.40956238550359558293e-01" " 1.93176064914911044257e-01" " 1.93865537514476327097e-01" " 1.00000000000000000000e+00"
-" 4.77625197262214196137e-01" " 2.05576215076779522661e+00" "-1.55471040919639896805e-01" "-1.84436652285859509215e-01" "-4.00166527997676102490e-01" "-1.03568764489028797282e-01" " 3.36072910549359005206e-01" " 2.01980837800672108351e-01" " 2.01543799544738971852e-01" " 1.00000000000000000000e+00" " 3.36376975414062917569e-01" " 2.02163343849419724352e-01" " 2.01950788170536438271e-01" " 1.00000000000000000000e+00"
-" 4.78087649402390457709e-01" " 2.05600560617205774250e+00" "-1.56107974585544484469e-01" "-1.83829363744616058884e-01" "-4.01820120271884184682e-01" "-1.02412901287741969769e-01" " 3.36824825766857349763e-01" " 2.02619177958996060651e-01" " 2.02757487818918391564e-01" " 1.00000000000000000000e+00" " 3.36824825766857349763e-01" " 2.02619177958996060651e-01" " 2.02757487818918391564e-01" " 1.00000000000000000000e+00"
-" 4.97913504345446511490e-01" " 2.06649991357224971367e+00" "-1.53375495014640150782e-01" "-1.84672353507325415212e-01" "-3.98578030814480621657e-01" "-1.00919636345967039803e-01" " 3.31055955619719899374e-01" " 2.10177295430298449741e-01" " 2.09665955518348795517e-01" " 1.00000000000000000000e+00" " 3.31250290827163951235e-01" " 2.10233737334792170071e-01" " 2.10218765523974088216e-01" " 1.00000000000000000000e+00"
[TRUNCATED]

To get the complete diff run:
    svnlook diff /svnroot/robast -r 637


More information about the Robast-commits mailing list
--- branches/robast-0.9/pkg/RobExtremes/inst/AddMaterial/interpolation/plotInterpol.R	2013-03-15 14:12:31 UTC (rev 636)
+++ branches/robast-0.9/pkg/RobExtremes/inst/AddMaterial/interpolation/plotInterpol.R	2013-03-16 11:25:54 UTC (rev 637)
@@ -1,5 +1,7 @@
 plotLM <- function(Gridnam,Famnam,whichLM, baseDir="C:/rtest/robast",
-               withSmooth=FALSE, gridRestriction = NULL, prehook={}, posthook={}, ...){
+               withSmooth = FALSE, plotGridRestriction = NULL,
+               smoothtry = FALSE, df = NULL, gridRestrForSmooth = NULL,
+               prehook={}, posthook={}, ...){
    ## Gridnam in (Sn,OMSE,RMXE,MBRE) ## uses partial matching!!
    ## Famnam in "Generalized Pareto Family", ## uses partial matching!!
    ##           "GEV Family",
@@ -13,14 +15,41 @@
    #                                       (A12.i+A21.i)/2,A.22.i), 2, 2),
    ##                 and optIC = Y.a min(1,b/norm(Y.i)), Y.* = A.* Lambda - a.*
    ##          or "all" then all LMs are plotted
    ## basedir: Oberverzeichnis des r-forge svn checkouts
    ## gridRestriction: an expression that can be used as index in xi[gridRestriction]
    ##                  to restrict the plotted grid-values
    ## prehook: an expression to be evaluated before plotting --- typically something
    ##          like pdf("myfile.pdf")
    ## posthook: an expression to be evaluated after plotting --- typically something
    ##          like dev.off()
-   ## withSmooth: logical shall item grid or gridS be used for plotting
+   ## withSmooth: logical; shall item grid or gridS be used for plotting
+   ## ---------------------------
+   ###  for interactive try-out of several smoothing values
+   ##
+   ## smoothtry: logical; shall interactive try-out of smoothing be used
+   ##            if TRUE overrides withSmooth
+   ## df: smoothing parameter (see below)
+   ## gridRestrForSmooth: restriction of smoothing for particular theta-grid-values
+   ##        (see below)
+   ###
+   ## copied from help to .MakeSmoothGridList
+   ##
+#   \item{df}{argument \code{df} of \code{\link{smooth.spline}}; if \code{NULL}
+#            (default) it is omitted (and the default of
+#            \code{\link{smooth.spline}} used); controls the degree to which
+#            we smooth; can be vectorized; to allow for \code{NULL}-entries
+#            in some (of the 13) LMs, it can also be a list of length 13,
+#            some entries being \code{NULL}, some numeric. }
+#  \item{gridRestrForSmooth}{an expression that can be used as index in
+#     \code{theta[gridRestrForSmooth]} to restrict the grid-values to
+#     be smoothed; the excluded grid values are left unchanged. If the argument
+#     is \code{NULL} no restriction is used. Can be a matrix of same dimension
+#     as the \code{Y}-grid to allow for column-individual restrictions,
+#     or a list of same length as number of columns of \code{Y}
+#     with columnwise restrictions of \code{Y} (and \code{NULL} entries
+#     are interpreted as no restriction). }
+
    file <- file.path(baseDir, "branches/robast-0.9/pkg/RobAStRDA/R/sysdata.rda")
    if(!file.exists(file)) stop("Fehler mit Checkout")
    nE <- new.env()
@@ -39,15 +68,23 @@
    GN0 <- Gridnam; if(isSn) GN0 <- "SnGrids"
    GN <- paste(".",GN0,sep="")
    funN <- paste("fun",".",if(getRversion()<"2.16") "O" else "N",sep="")
-   gN <- if(withSmooth) "gridS" else "grid"
-   gr <- get(GN,envir=nE)[[Famnam0]][[gN]]
-   if(is.null(gridRestriction)) gridRestriction <- rep(TRUE, nrow(gr))
+   if(!smoothtry){
+      gN <- if(withSmooth) "gridS" else "grid"
+      gr <- get(GN,envir=nE)[[Famnam0]][[gN]]
+   }else{
+     gr <- get(GN,envir=nE)[[Famnam0]][["grid"]]
+#     gr <- RobAStRDA:::.MakeSmoothGridList(gr[,1],gr[,-1], df = df,
+#                        gridRestrForSmooth = gridRestrForSmooth)
+     gr <- .MakeSmoothGridList(gr[,1],gr[,-1], df = df,
+                        gridRestrForSmooth = gridRestrForSmooth)
+   }
+   if(is.null(plotGridRestriction)) plotGridRestriction <- rep(TRUE, nrow(gr))
    if(!isSn) if(whichLM!="all") if(whichLM<1 | whichLM>13) stop("Falsche Koordinate")
    if(!isSn) if(whichLM=="all"){
       eval(prehook)
       par(mfrow=c(4,4))
       for(i in 2:14)
-          plot(gr[gridRestriction,1], gr[gridRestriction,i], ...)
+          plot(gr[plotGridRestriction,1], gr[plotGridRestriction,i], ...)
       par(mfrow=c(1,1))
       eval(posthook)
    return(invisible(NULL))
@@ -62,17 +99,19 @@
 
 if(FALSE){
 ## Examples
-plotLM("OMSE","Gamma","all", type="l", gridR=-(1:20))
-plotLM("OMSE","Pareto","all", type="l", gridR=-(1:20))
-plotLM("OMSE","Gener","all", type="l", gridR=-(1:20))
-plotLM("OMSE","GEV","all", type="l", gridR=-(1:20))
-plotLM("OMSE","Wei","all", type="l", gridR=-(1:20))
-plotLM("MBRE","Wei","all", type="l", gridR=-(1:20))
-plotLM("MBRE","GE","all", type="l", gridR=-(1:20))
-plotLM("MBRE","Gene","all", type="l", gridR=-(1:20))
-plotLM("MBRE","Gam","all", type="l", gridR=-(1:20))
-plotLM("RMXE","Gam","all", type="l", gridR=-(1:20))
-plotLM("RMXE","Wei","all", type="l", gridR=-(1:20))
-plotLM("RMXE","Gene","all", type="l", gridR=-(1:20))
-plotLM("RMXE","GE","all", type="l", gridR=-(1:20))
+plotLM("OMSE","Gamma","all", type="l", plotG=-(1:8))
+plotLM("OMSE","Gener","all", type="l", plotG=-(1:8))
+plotLM("OMSE","GEV","all", type="l", plotG=-(1:8))
+plotLM("OMSE","Wei","all", type="l", plotG=-(1:8))
+plotLM("MBRE","Wei","all", type="l", plotG=-(1:8))
+plotLM("MBRE","GE","all", type="l", plotG=-(1:8))
+plotLM("MBRE","Gene","all", type="l", plotG=-(1:8))
+plotLM("MBRE","Gam","all", type="l", plotG=-(1:8))
+plotLM("RMXE","Gam","all", type="l", plotG=-(1:8))
+plotLM("RMXE","Wei","all", type="l", plotG=-(1:8))
+plotLM("RMXE","Gene","all", type="l", plotG=-(1:8))
+plotLM("RMXE","GE","all", type="l", plotG=-(1:8))
+plotLM("MBRE","GE","all", type="l")
+plotLM("MBRE","GE","all", type="l", sm = TRUE, df = 10, gridR = -(1:15))
+plotLM("MBRE","GE","all", type="l", sm = TRUE, df = 4, gridR = -(1:15))
 }
\ No newline at end of file
@@ -13,14 +15,41 @@
    ##                 and optIC = Y.a min(1,b/norm(Y.i)), Y.* = A.* Lambda - a.*
    ##          or "all" then all LMs are plotted
-   ## basedir: Oberverzeichnis des r-forge svn checkouts
-   ## gridRestriction: an expression that can be used as index in xi[gridRestriction]
-   ##                  to restrict the plotted grid-values
+   ## basedir: folder with r-forge svn checkout
+   ## plotGridRestriction: an expression that can be used as index in
+   ##                      xi[plotGridRestriction] to restrict the plotted
+   ##                      grid-values
    ## prehook: an expression to be evaluated before plotting --- typically something
    ##          like pdf("myfile.pdf")

Modified: branches/robast-0.9/pkg/RobExtremesBuffer/interpolMBREGEVFamily.csv
===================================================================